@@ -65,7 +65,7 @@ parse_collate <- function(string) {
 #' Find all R files in given directory.
 #' @keywords internal
 find_code <- function(path) {
-  code_paths <- dir(path, "\\.[Rr]$", full.names = TRUE)  
+  code_paths <- dir(path, "\\.[Rrq]$", full.names = TRUE)  
   with_collate("C", sort(code_paths))
 }
 
