@@ -4,11 +4,12 @@
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
+#' @param deps dependencies to be loaded (e.g. "depends", "imports", "suggests", "enhances")
 #' @keywords programming
 #' @export
-load_deps <- function(pkg = NULL) {
+load_deps <- function(pkg = NULL, deps = c("suggests", "depends", "imports")) {
   pkg <- as.package(pkg)
-  deps <- c(parse_deps(pkg$depends), parse_deps(pkg$imports))
+  deps <- unlist(lapply(pkg[deps], parse_deps))
   
   if (length(deps) == 0) return(invisible())
   
