@@ -1,6 +1,6 @@
 context("Documentation checks")
 
 test_that("invalid DESCRIPTION gives warning", {
-  expect_message(check_doc("invalid-description"), 
+  expect_message(load_all("invalid-description"), 
     c("invalid DESCRIPTION", "fields missing"))
 })
\ No newline at end of file
